@@ -19,6 +19,7 @@
 # THE SOFTWARE.
 
 from . import matchers
+import operator
 from . import signature
 from . import verification as verificationModule
 from .utils import contains_strict
@@ -31,6 +32,12 @@ class InvocationError(AttributeError):
     pass
 
 
+__tracebackhide__ = operator.methodcaller(
+    "errisinstance",
+    (InvocationError, verificationModule.VerificationError)
+)
+
+
 class Invocation(object):
     def __init__(self, mock, method_name):
         self.mock = mock
@@ -49,7 +56,7 @@ class Invocation(object):
                 for p in self.params]
         kwargs = ["%s=%r" % (key, val)
                   if key is not matchers.KWARGS_SENTINEL else '**kwargs'
-                  for key, val in list(self.named_params.items())]
+                  for key, val in self.named_params.items()]
         params = ", ".join(args + kwargs)
         return "%s(%s)" % (self.method_name, params)
 
@@ -89,18 +96,29 @@ class RememberedInvocation(Invocation):
                     *params, **named_params)
 
         if self.strict:
-            stubbed_invocations = self.mock.stubbed_invocations or [None]
-            raise InvocationError("""
-You called
+            stubbed_invocations = [
+                invoc
+                for invoc in self.mock.stubbed_invocations
+                if invoc.method_name == self.method_name
+            ]
+            raise InvocationError(
+                """
+Called but not expected:
 
-        %s,
+    %s
 
-which is not expected. Stubbed invocations are:
+Stubbed invocations are:
 
-        %s
+    %s
 
-(Set strict to False to bypass this check.)
-""" % (self, "\n    ".join(str(invoc) for invoc in stubbed_invocations)))
+"""
+                % (
+                    self,
+                    "\n    ".join(
+                        str(invoc) for invoc in reversed(stubbed_invocations)
+                    )
+                )
+            )
 
         return None
 
@@ -160,8 +178,7 @@ class MatchingInvocation(Invocation):
             return p
 
         self.params = tuple(wrap(p) for p in params)
-        self.named_params = {k: wrap(v) for k, v in list(named_params.items())}
-
+        self.named_params = {k: wrap(v) for k, v in named_params.items()}
 
     # Note: matches(a, b) does not imply matches(b, a) because
     # the left side might contain wildcards (like Ellipsis) or matchers.
@@ -190,7 +207,7 @@ class MatchingInvocation(Invocation):
                 return False
 
         for key, p1 in sorted(
-            iter(self.named_params.items()),
+            self.named_params.items(),
             key=lambda k_v: 1 if k_v[0] is matchers.KWARGS_SENTINEL else 0
         ):
             if key is matchers.KWARGS_SENTINEL:
@@ -238,12 +255,16 @@ class VerifiableInvocation(MatchingInvocation):
 
 
 def verification_has_lower_bound_of_zero(verification):
-    if (isinstance(verification, verificationModule.Times) and
-            verification.wanted_count == 0):
+    if (
+        isinstance(verification, verificationModule.Times)
+        and verification.wanted_count == 0
+    ):
         return True
 
-    if (isinstance(verification, verificationModule.Between) and
-            verification.wanted_from == 0):
+    if (
+        isinstance(verification, verificationModule.Between)
+        and verification.wanted_from == 0
+    ):
         return True
 
     return False
